@@ -26,15 +26,63 @@ FAILEDOPERATION_CERTIFICATEHASEXPIRED = 'FailedOperation.CertificateHasExpired'
 # 证书不存在。
 FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'
 
-# 账户余额不足
+# 配置文件Condition表达式语法错误。
+FAILEDOPERATION_CONFIGCONDITIONSYNTAXERROR = 'FailedOperation.ConfigConditionSyntaxError'
+
+# 无法识别的Condition匹配类型。
+FAILEDOPERATION_CONFIGCONDITIONUNKNOWNTARGET = 'FailedOperation.ConfigConditionUnknownTarget'
+
+# 配置文件Condition表达式值的项不能为空。
+FAILEDOPERATION_CONFIGCONDITIONVALUEEMPTYERROR = 'FailedOperation.ConfigConditionValueEmptyError'
+
+# 配置文件存在类型不匹配的字段。
+FAILEDOPERATION_CONFIGFIELDTYPEERROR = 'FailedOperation.ConfigFieldTypeError'
+
+# 配置文件存在语法错误。
+FAILEDOPERATION_CONFIGFORMATERROR = 'FailedOperation.ConfigFormatError'
+
+# 配置文件内容格式错误，无法解析。
+FAILEDOPERATION_CONFIGMALFORMEDCONTENT = 'FailedOperation.ConfigMalformedContent'
+
+# 配置文件参数校验错误。
+FAILEDOPERATION_CONFIGPARAMVALIDATEERRORS = 'FailedOperation.ConfigParamValidateErrors'
+
+# 配置文件无法识别的字段：存在拼写错误，或者该字段所在的层级出错。
+FAILEDOPERATION_CONFIGUNKNOWNFIELD = 'FailedOperation.ConfigUnknownField'
+
+# 当前不支持该配置文件版本。
+FAILEDOPERATION_CONFIGUNSUPPORTEDFORMATVERSION = 'FailedOperation.ConfigUnsupportedFormatVersion'
+
+# 创建日志集失败，请检查日志集名是否已存在。
+FAILEDOPERATION_CREATECLSLOGSETFAILED = 'FailedOperation.CreateClsLogSetFailed'
+
+# 创建日志主题任务失败，请检查日志主题名或任务名是否已存在。
+FAILEDOPERATION_CREATECLSLOGTOPICTASKFAILED = 'FailedOperation.CreateClsLogTopicTaskFailed'
+
+# 创建自定义推送任务认证失败, 请检查推送地址是否正确。
+FAILEDOPERATION_CREATELOGTOPICTASKAUTHFAILURE = 'FailedOperation.CreateLogTopicTaskAuthFailure'
+
+# 账户余额不足。
 FAILEDOPERATION_INSUFFICIENTACCOUNTBALANCE = 'FailedOperation.InsufficientAccountBalance'
 
 # 站点状态不正确。
 FAILEDOPERATION_INVALIDZONESTATUS = 'FailedOperation.InvalidZoneStatus'
 
+# content缺少必带的配置块。
+FAILEDOPERATION_MISSINGCONFIGCHUNK = 'FailedOperation.MissingConfigChunk'
+
 # 操作失败。
 FAILEDOPERATION_MODIFYFAILED = 'FailedOperation.ModifyFailed'
 
+# 实时日志认证失败
+FAILEDOPERATION_REALTIMELOGAUTHFAILURE = 'FailedOperation.RealtimeLogAuthFailure'
+
+# 实时日志推送任务不存在
+FAILEDOPERATION_REALTIMELOGNOTFOUND = 'FailedOperation.RealtimeLogNotFound'
+
+# 未知的配置组类型。
+FAILEDOPERATION_UNKNOWNCONFIGGROUPTYPE = 'FailedOperation.UnknownConfigGroupType'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -107,6 +155,9 @@ INVALIDPARAMETER_CLIENTIPCOUNTRYCONFLICTSWITHIPV6 = 'InvalidParameter.ClientIpCo
 # CNAME模式下无法申请泛域名证书。
 INVALIDPARAMETER_CNAMEWILDHOSTNOTALLOWAPPLYCERTIFICATE = 'InvalidParameter.CnameWildHostNotAllowApplyCertificate'
 
+# 无效的压缩算法。
+INVALIDPARAMETER_COMPRESSIONINVALIDALGORITHMS = 'InvalidParameter.CompressionInvalidAlgorithms'
+
 # 源站不能和域名一致。
 INVALIDPARAMETER_CONFLICTHOSTORIGIN = 'InvalidParameter.ConflictHostOrigin'
 
@@ -116,6 +167,9 @@ INVALIDPARAMETER_DOMAINNOTFOUND = 'InvalidParameter.DomainNotFound'
 # 当前域名已开启流量调度功能。
 INVALIDPARAMETER_DOMAINONTRAFFICSCHEDULING = 'InvalidParameter.DomainOnTrafficScheduling'
 
+# 重复规则。
+INVALIDPARAMETER_DUPLICATERULE = 'InvalidParameter.DuplicateRule'
+
 # 操作不支持条件。
 INVALIDPARAMETER_ERRACTIONUNSUPPORTTARGET = 'InvalidParameter.ErrActionUnsupportTarget'
 
@@ -125,6 +179,9 @@ INVALIDPARAMETER_ERRINVALIDACTION = 'InvalidParameter.ErrInvalidAction'
 # 非法操作-操作配置重复。
 INVALIDPARAMETER_ERRINVALIDACTIONDUPLICATEACTION = 'InvalidParameter.ErrInvalidActionDuplicateAction'
 
+# 无效的规则引擎操作，源站IP不支持内网IP或回环地址。
+INVALIDPARAMETER_ERRINVALIDACTIONORIGINPRIVATEADDRESS = 'InvalidParameter.ErrInvalidActionOriginPrivateAddress'
+
 # 非法操作-非法参数。
 INVALIDPARAMETER_ERRINVALIDACTIONPARAM = 'InvalidParameter.ErrInvalidActionParam'
 
@@ -152,6 +209,9 @@ INVALIDPARAMETER_ERRINVALIDACTIONTYPE = 'InvalidParameter.ErrInvalidActionType'
 # 非法条件。
 INVALIDPARAMETER_ERRINVALIDCONDITION = 'InvalidParameter.ErrInvalidCondition'
 
+# 修改源站操作不能仅配置host匹配类型。
+INVALIDPARAMETER_ERRINVALIDCONDITIONCANNOTONLYCONTAINHOSTWHENMODIFYORIGINACTIONCONFIGURED = 'InvalidParameter.ErrInvalidConditionCannotOnlyContainHostWhenModifyOriginActionConfigured'
+
 # 修改源站操作仅支持配置一个host匹配类型。
 INVALIDPARAMETER_ERRINVALIDCONDITIONHOSTTOOMANYWHENMODIFYORIGINACTIONCONFIGURED = 'InvalidParameter.ErrInvalidConditionHostTooManyWhenModifyOriginActionConfigured'
 
@@ -230,6 +290,9 @@ INVALIDPARAMETER_INVALIDAUTHENTICATIONTYPETIMEFORMAT = 'InvalidParameter.Invalid
 # 无效的token鉴权时间参数。
 INVALIDPARAMETER_INVALIDAUTHENTICATIONTYPETIMEPARAM = 'InvalidParameter.InvalidAuthenticationTypeTimeParam'
 
+# 自动使用代金券格式不正确，请输入正确的自动使用代金券格式。
+INVALIDPARAMETER_INVALIDAUTOUSEVOUCHER = 'InvalidParameter.InvalidAutoUseVoucher'
+
 # 无效的第三方对象存储。
 INVALIDPARAMETER_INVALIDAWSPRIVATEACCESS = 'InvalidParameter.InvalidAwsPrivateAccess'
 
@@ -257,6 +320,9 @@ INVALIDPARAMETER_INVALIDCACHEKEYCOOKIE = 'InvalidParameter.InvalidCacheKeyCookie
 # 无效的缓存键忽略大小写。
 INVALIDPARAMETER_INVALIDCACHEKEYIGNORECASE = 'InvalidParameter.InvalidCacheKeyIgnoreCase'
 
+# 无效的查询字符串。
+INVALIDPARAMETER_INVALIDCACHEKEYQUERYSTRINGACTION = 'InvalidParameter.InvalidCacheKeyQueryStringAction'
+
 # 无效的查询字符串。
 INVALIDPARAMETER_INVALIDCACHEKEYQUERYSTRINGVALUE = 'InvalidParameter.InvalidCacheKeyQueryStringValue'
 
@@ -272,12 +338,18 @@ INVALIDPARAMETER_INVALIDCACHETIME = 'InvalidParameter.InvalidCacheTime'
 # 证书信息错误。
 INVALIDPARAMETER_INVALIDCERTINFO = 'InvalidParameter.InvalidCertInfo'
 
+# 无效的客户端IP地理位置配置，HeaderName由1-100个字母或数字组成的，不能以"-"开头或结尾。
+INVALIDPARAMETER_INVALIDCLIENTIPCOUNTRYHEADERNAME = 'InvalidParameter.InvalidClientIpCountryHeaderName'
+
 # 无效的客户端IP请求头。
 INVALIDPARAMETER_INVALIDCLIENTIPHEADERNAME = 'InvalidParameter.InvalidClientIpHeaderName'
 
 # 分区域回源的源站无效。
 INVALIDPARAMETER_INVALIDCLIENTIPORIGIN = 'InvalidParameter.InvalidClientIpOrigin'
 
+# 不合法的条件。
+INVALIDPARAMETER_INVALIDCONDITIONS = 'InvalidParameter.InvalidConditions'
+
 # 无效的回源配置，源站类型为对象存储时，源站地址必须为对象存储域名。
 INVALIDPARAMETER_INVALIDCOSDOMAIN = 'InvalidParameter.InvalidCosDomain'
 
@@ -311,21 +383,54 @@ INVALIDPARAMETER_INVALIDHTTPSHSTSMAXAGE = 'InvalidParameter.InvalidHttpsHstsMaxA
 # 无效的HTTPS TLS版本。
 INVALIDPARAMETER_INVALIDHTTPSTLSVERSION = 'InvalidParameter.InvalidHttpsTlsVersion'
 
+# 无效时间间隔。取值应为[min 5min hour day]。
+INVALIDPARAMETER_INVALIDINTERVAL = 'InvalidParameter.InvalidInterval'
+
 # 无效的Ipv6开关配置。
 INVALIDPARAMETER_INVALIDIPV6SWITCH = 'InvalidParameter.InvalidIpv6Switch'
 
+# 日志输出格式的字段分隔符不正确
+INVALIDPARAMETER_INVALIDLOGFORMATFIELDDELIMITER = 'InvalidParameter.InvalidLogFormatFieldDelimiter'
+
+# 日志输出格式类型不正确
+INVALIDPARAMETER_INVALIDLOGFORMATFORMATTYPE = 'InvalidParameter.InvalidLogFormatFormatType'
+
+# 日志输出格式的日志记录分隔符不正确
+INVALIDPARAMETER_INVALIDLOGFORMATRECORDDELIMITER = 'InvalidParameter.InvalidLogFormatRecordDelimiter'
+
+# 无效的浏览器缓存。
+INVALIDPARAMETER_INVALIDMAXAGEFOLLOWORIGIN = 'InvalidParameter.InvalidMaxAgeFollowOrigin'
+
 # 无效的浏览器缓存。
 INVALIDPARAMETER_INVALIDMAXAGETIME = 'InvalidParameter.InvalidMaxAgeTime'
 
+# 无效查询维度。
+INVALIDPARAMETER_INVALIDMETRIC = 'InvalidParameter.InvalidMetric'
+
 # 无效的源站。
 INVALIDPARAMETER_INVALIDORIGIN = 'InvalidParameter.InvalidOrigin'
 
+# 源站组类型错误。
+INVALIDPARAMETER_INVALIDORIGINGROUPTYPE = 'InvalidParameter.InvalidOriginGroupType'
+
 # 不支持填写内网IP/回环地址作为源站地址
 INVALIDPARAMETER_INVALIDORIGINIP = 'InvalidParameter.InvalidOriginIp'
 
+# 源站类型错误。
+INVALIDPARAMETER_INVALIDORIGINTYPE = 'InvalidParameter.InvalidOriginType'
+
+# 源站错误或不存在。
+INVALIDPARAMETER_INVALIDORIGINVALUE = 'InvalidParameter.InvalidOriginValue'
+
 # 参数错误。
 INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
 
+# 套餐周期格式不正确，请输入正确的套餐周期格式。
+INVALIDPARAMETER_INVALIDPERIOD = 'InvalidParameter.InvalidPeriod'
+
+# 套餐类型格式不正确，请输入正确的套餐类型格式。
+INVALIDPARAMETER_INVALIDPLANTYPE = 'InvalidParameter.InvalidPlanType'
+
 # 套餐包不支持最大上传大小。
 INVALIDPARAMETER_INVALIDPOSTMAXSIZEBILLING = 'InvalidParameter.InvalidPostMaxSizeBilling'
 
@@ -341,9 +446,18 @@ INVALIDPARAMETER_INVALIDPRIVATEACCESSSWITCH = 'InvalidParameter.InvalidPrivateAc
 # 套餐包不支持Quic配置。
 INVALIDPARAMETER_INVALIDQUICBILLING = 'InvalidParameter.InvalidQuicBilling'
 
+# 配额数量格式不正确，请输入正确的配额数量格式。
+INVALIDPARAMETER_INVALIDQUOTANUMBER = 'InvalidParameter.InvalidQuotaNumber'
+
+# 配额类型格式不正确，请输入正确的配额类型格式。
+INVALIDPARAMETER_INVALIDQUOTATYPE = 'InvalidParameter.InvalidQuotaType'
+
 # 无效的分片回源。
 INVALIDPARAMETER_INVALIDRANGEORIGINPULL = 'InvalidParameter.InvalidRangeOriginPull'
 
+# 自动续费标志格式不正确，请输入正确的自动续费标签格式。
+INVALIDPARAMETER_INVALIDRENEWFLAG = 'InvalidParameter.InvalidRenewFlag'
+
 # 无效的请求头header。
 INVALIDPARAMETER_INVALIDREQUESTHEADERNAME = 'InvalidParameter.InvalidRequestHeaderName'
 
@@ -377,12 +491,21 @@ INVALIDPARAMETER_INVALIDRULEENGINETARGETSEXTENSION = 'InvalidParameter.InvalidRu
 # 无效的规则引擎URL条件。
 INVALIDPARAMETER_INVALIDRULEENGINETARGETSURL = 'InvalidParameter.InvalidRuleEngineTargetsUrl'
 
+# 规则协议错误。（TCP/UDP）。
+INVALIDPARAMETER_INVALIDRULEPROTO = 'InvalidParameter.InvalidRuleProto'
+
 # 无效的回源Host。
 INVALIDPARAMETER_INVALIDSERVERNAME = 'InvalidParameter.InvalidServerName'
 
+# edgeone的debug配置无效。
+INVALIDPARAMETER_INVALIDSTANDARDDEBUG = 'InvalidParameter.InvalidStandardDebug'
+
 # 无效的客户端ip或ip段。
 INVALIDPARAMETER_INVALIDSTANDARDDEBUGCLIENTIP = 'InvalidParameter.InvalidStandardDebugClientIp'
 
+# AllowClientIPList 参数必填，支持 IPv4 及 IPv6 网段。0.0.0.0/0 表示允许所有 IPv4 客户端进行调试，::/0 表示允许所有 IPv6 客户端进行调试。
+INVALIDPARAMETER_INVALIDSTANDARDDEBUGEMPTYLIST = 'InvalidParameter.InvalidStandardDebugEmptyList'
+
 # 有效期超过限制。
 INVALIDPARAMETER_INVALIDSTANDARDDEBUGEXPIRETIMELIMIT = 'InvalidParameter.InvalidStandardDebugExpireTimeLimit'
 
@@ -407,6 +530,9 @@ INVALIDPARAMETER_KEYRULESINVALIDQUERYSTRINGVALUE = 'InvalidParameter.KeyRulesInv
 # 参数长度超过限制。
 INVALIDPARAMETER_LENGTHEXCEEDSLIMIT = 'InvalidParameter.LengthExceedsLimit'
 
+# 修改源站操作中负载均衡实例Id必填。
+INVALIDPARAMETER_LOADBALANCEINSTANCEIDISREQUIRED = 'InvalidParameter.LoadBalanceInstanceIdIsRequired'
+
 # 不支持智能路由
 INVALIDPARAMETER_MULTIPLYLAYERNOTSUPPORTSMARTROUTING = 'InvalidParameter.MultiplyLayerNotSupportSmartRouting'
 
@@ -419,15 +545,30 @@ INVALIDPARAMETER_OCDIRECTORIGINREQUIRESSMARTROUTING = 'InvalidParameter.OCDirect
 # 源站是内网IP。
 INVALIDPARAMETER_ORIGINISINNERIP = 'InvalidParameter.OriginIsInnerIp'
 
+# 四层代理禁止IP域名混填。
+INVALIDPARAMETER_ORIGINL4RECORDIPV4MIXDOMAIN = 'InvalidParameter.OriginL4RecordIPV4MixDomain'
+
+# 四层代理禁止使用多域名源站。
+INVALIDPARAMETER_ORIGINL4RECORDMULTIDOMAIN = 'InvalidParameter.OriginL4RecordMultiDomain'
+
 # 源站组名称已经存在。
 INVALIDPARAMETER_ORIGINNAMEEXISTS = 'InvalidParameter.OriginNameExists'
 
 # 修改源站操作中源站组Id必填。
 INVALIDPARAMETER_ORIGINORIGINGROUPIDISREQUIRED = 'InvalidParameter.OriginOriginGroupIdIsRequired'
 
+# 修改源站操作中回源协议必填。
+INVALIDPARAMETER_ORIGINPULLPROTOCOLISREQUIRED = 'InvalidParameter.OriginPullProtocolIsRequired'
+
 # 源站格式错误。
 INVALIDPARAMETER_ORIGINRECORDFORMATERROR = 'InvalidParameter.OriginRecordFormatError'
 
+# 权重取值范围：0 - 100。
+INVALIDPARAMETER_ORIGINRECORDWEIGHTVALUE = 'InvalidParameter.OriginRecordWeightValue'
+
+# 密钥格式错误。
+INVALIDPARAMETER_ORIGINTHIRDPARTYPARAMFORMATERROR = 'InvalidParameter.OriginThirdPartyParamFormatError'
+
 # 参数错误: 无效 "结束时间", 不在允许的查询范围内: [开始时间, 开始+ 7天]
 INVALIDPARAMETER_PARAMETERERROR = 'InvalidParameter.ParameterError'
 
@@ -440,6 +581,27 @@ INVALIDPARAMETER_POSTMAXSIZELIMITEXCEEDED = 'InvalidParameter.PostMaxSizeLimitEx
 # 实例名称重复。
 INVALIDPARAMETER_PROXYNAMEDUPLICATING = 'InvalidParameter.ProxyNameDuplicating'
 
+# 实例名称可输入1-50个字符，允许的字符为a-z、0-9、-，- 不能单独注册或连续使用，不能放在开头或结尾。
+INVALIDPARAMETER_PROXYNAMENOTMATCHED = 'InvalidParameter.ProxyNameNotMatched'
+
+# 推送实例已经创建
+INVALIDPARAMETER_REALTIMELOGENTITYALREADYCREATED = 'InvalidParameter.RealtimeLogEntityAlreadyCreated'
+
+# 日志推送地域不合法
+INVALIDPARAMETER_REALTIMELOGINVALIDDELIVERYAREA = 'InvalidParameter.RealtimeLogInvalidDeliveryArea'
+
+# 日志推送类型不合法
+INVALIDPARAMETER_REALTIMELOGINVALIDLOGTYPE = 'InvalidParameter.RealtimeLogInvalidLogType'
+
+# 实时日志数据投递类型不合法
+INVALIDPARAMETER_REALTIMELOGINVALIDTASKTYPE = 'InvalidParameter.RealtimeLogInvalidTaskType'
+
+# 实时日志推送任务数据超过了限制
+INVALIDPARAMETER_REALTIMELOGNUMSEXCEEDLIMIT = 'InvalidParameter.RealtimeLogNumsExceedLimit'
+
+# 无效的响应头header。
+INVALIDPARAMETER_RESPONSEHEADERCACHECONTROLNOTALLOWDELETE = 'InvalidParameter.ResponseHeaderCacheControlNotAllowDelete'
+
 # 规则源站信息格式错误。
 INVALIDPARAMETER_RULEORIGINFORMATERROR = 'InvalidParameter.RuleOriginFormatError'
 
@@ -470,6 +632,9 @@ INVALIDPARAMETER_SETTINGINVALIDPARAM = 'InvalidParameter.SettingInvalidParam'
 # Shield Space 未绑定源站，请先绑定源站后重试。
 INVALIDPARAMETER_SPACENOTBINDORIGIN = 'InvalidParameter.SpaceNotBindOrigin'
 
+# 状态码缓存的状态码无效。
+INVALIDPARAMETER_STATUSCODECACHEINVALIDSTATUSCODE = 'InvalidParameter.StatusCodeCacheInvalidStatusCode'
+
 # 资源存在错误。
 INVALIDPARAMETER_TARGET = 'InvalidParameter.Target'
 
@@ -479,6 +644,9 @@ INVALIDPARAMETER_TASKNOTGENERATED = 'InvalidParameter.TaskNotGenerated'
 # 内部错误。
 INVALIDPARAMETER_TASKSYSTEMERROR = 'InvalidParameter.TaskSystemError'
 
+# HTTPS的TLS版本不连续。
+INVALIDPARAMETER_TLSVERSIONNOTINSEQUENCE = 'InvalidParameter.TlsVersionNotInSequence'
+
 # 过滤值过多。
 INVALIDPARAMETER_TOOMANYFILTERVALUES = 'InvalidParameter.TooManyFilterValues'
 
@@ -488,6 +656,9 @@ INVALIDPARAMETER_UPLOADURL = 'InvalidParameter.UploadUrl'
 # 站点已被绑定。
 INVALIDPARAMETER_ZONEHASBEENBOUND = 'InvalidParameter.ZoneHasBeenBound'
 
+# 站点未绑定套餐。
+INVALIDPARAMETER_ZONEHASNOTBEENBOUNDTOPLAN = 'InvalidParameter.ZoneHasNotBeenBoundToPlan'
+
 # 站点升级中，暂不支持进行变更操作，请稍后再试。
 INVALIDPARAMETER_ZONEISGRAYPUBLISHING = 'InvalidParameter.ZoneIsGrayPublishing'
 
@@ -500,6 +671,9 @@ INVALIDPARAMETER_ZONENOTFOUND = 'InvalidParameter.ZoneNotFound'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 该站点域名已被禁用。
+INVALIDPARAMETERVALUE_ACCESSBLACKLIST = 'InvalidParameterValue.AccessBlacklist'
+
 # 与已经添加的记录冲突。
 INVALIDPARAMETERVALUE_CONFLICTRECORD = 'InvalidParameterValue.ConflictRecord'
 
@@ -515,6 +689,9 @@ INVALIDPARAMETERVALUE_CONTENTSAMEASNAME = 'InvalidParameterValue.ContentSameAsNa
 # 入参中的域名与站点参数不匹配，请更正后重试。
 INVALIDPARAMETERVALUE_DOMAINNOTMATCHZONE = 'InvalidParameterValue.DomainNotMatchZone'
 
+# 别称域名名称不合法，别称域名应该由数字、英文字母、连词符组成，且连词符不能位于开头和结尾处。
+INVALIDPARAMETERVALUE_INVALIDALIASDOMAINNAME = 'InvalidParameterValue.InvalidAliasDomainName'
+
 # 无效的别称域名后缀（该域名为内部接入域名，暂不支持作为别称域名接入）。
 INVALIDPARAMETERVALUE_INVALIDALIASNAMESUFFIX = 'InvalidParameterValue.InvalidAliasNameSuffix'
 
@@ -533,6 +710,9 @@ INVALIDPARAMETERVALUE_INVALIDDOMAINSTATUS = 'InvalidParameterValue.InvalidDomain
 # DNS 代理域名源站错误。
 INVALIDPARAMETERVALUE_INVALIDPROXYORIGIN = 'InvalidParameterValue.InvalidProxyOrigin'
 
+# 标签值存在不合法字符。
+INVALIDPARAMETERVALUE_INVALIDTAGVALUE = 'InvalidParameterValue.InvalidTagValue'
+
 # 不支持接入泛域名 CNAME
 INVALIDPARAMETERVALUE_NOTALLOWEDWILDCARDSHAREDCNAME = 'InvalidParameterValue.NotAllowedWildcardSharedCNAME'
 
@@ -542,6 +722,18 @@ INVALIDPARAMETERVALUE_ORIGINGROUPNOTEXISTS = 'InvalidParameterValue.OriginGroupN
 # 请输入合法的共享 CNAME 前缀，最大支持50个字符。
 INVALIDPARAMETERVALUE_SHAREDCNAMEPREFIXNOTMATCH = 'InvalidParameterValue.SharedCNAMEPrefixNotMatch'
 
+# 暂不支持当前域名后缀接入，如您需要使用请联系我们。
+INVALIDPARAMETERVALUE_TOPLEVELDOMAINNOTSUPPORT = 'InvalidParameterValue.TopLevelDomainNotSupport'
+
+# 站点名称格式不正确，请输入正确的域名格式。
+INVALIDPARAMETERVALUE_ZONENAMEINVALID = 'InvalidParameterValue.ZoneNameInvalid'
+
+# 暂不支持 punycode 接入。
+INVALIDPARAMETERVALUE_ZONENAMENOTSUPPORTPUNYCODE = 'InvalidParameterValue.ZoneNameNotSupportPunyCode'
+
+# 站点不支持以子域名接入，请以二级域名作为站点接入。
+INVALIDPARAMETERVALUE_ZONENAMENOTSUPPORTSUBDOMAIN = 'InvalidParameterValue.ZoneNameNotSupportSubDomain'
+
 # 该同名站点标识已被占用，请重新输入。
 INVALIDPARAMETERVALUE_ZONESAMEASNAME = 'InvalidParameterValue.ZoneSameAsName'
 
@@ -557,18 +749,30 @@ LIMITEXCEEDED_DAILYQUOTA = 'LimitExceeded.DailyQuota'
 # 计费套餐不支持。
 LIMITEXCEEDED_PACKNOTALLOW = 'LimitExceeded.PackNotAllow'
 
+# 导入的规则数量超限制。
+LIMITEXCEEDED_PROXYRULESLIMITEXCEEDED = 'LimitExceeded.ProxyRulesLimitExceeded'
+
 # 查询时间范围超出限制。
 LIMITEXCEEDED_QUERYTIMELIMITEXCEEDED = 'LimitExceeded.QueryTimeLimitExceeded'
 
 # 单位时间内接口请求频率达到限制。
 LIMITEXCEEDED_RATELIMITEXCEEDED = 'LimitExceeded.RateLimitExceeded'
 
+# 规则数量达到限制。
+LIMITEXCEEDED_RULELIMITEXCEEDED = 'LimitExceeded.RuleLimitExceeded'
+
 # 超出功能限制。
 LIMITEXCEEDED_SECURITY = 'LimitExceeded.Security'
 
+# 用户实例数量限制。
+LIMITEXCEEDED_USERQUOTALIMITED = 'LimitExceeded.UserQuotaLimited'
+
 # 套餐可绑定的站点数量超过配额。
 LIMITEXCEEDED_ZONEBINDPLAN = 'LimitExceeded.ZoneBindPlan'
 
+# 缺少参数错误。
+MISSINGPARAMETER = 'MissingParameter'
+
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
@@ -578,12 +782,18 @@ OPERATIONDENIED_ACCELERATEMAINLANDDISABLE = 'OperationDenied.AccelerateMainlandD
 # 中国大陆加速与IPv6冲突，不能同时配置。
 OPERATIONDENIED_ACCELERATEMAINLANDIPV6CONFLICT = 'OperationDenied.AccelerateMainlandIpv6Conflict'
 
+# 当前站点下存在域名功能与中国大陆网络优化冲突，不能同时配置。
+OPERATIONDENIED_ACCELERATEMAINLANDMULTIPLYLAYERCONFLICT = 'OperationDenied.AccelerateMainlandMultiplyLayerConflict'
+
 # 引用源站组的7层域名服务正在部署中，请稍后再编辑。
 OPERATIONDENIED_ACCELERATIONDOMAINSTATUSNOTINONLINE = 'OperationDenied.AccelerationDomainStatusNotInOnline'
 
 # 配置已被锁定，请解除配置锁定之后在重试。
 OPERATIONDENIED_CONFIGLOCKED = 'OperationDenied.ConfigLocked'
 
+# 删除站点时预检查未通过。
+OPERATIONDENIED_DELETEZONEPRECHECKFAILED = 'OperationDenied.DeleteZonePreCheckFailed'
+
 # 站点停用未完毕，请稍后再试。
 OPERATIONDENIED_DISABLEZONENOTCOMPLETED = 'OperationDenied.DisableZoneNotCompleted'
 
@@ -599,6 +809,21 @@ OPERATIONDENIED_DOMAINNOICP = 'OperationDenied.DomainNoICP'
 # 站点下有域名时不允许修改服务区域。
 OPERATIONDENIED_DOMAINNUMBERISNOTZERO = 'OperationDenied.DomainNumberIsNotZero'
 
+# 站点内有域名处于非稳态，稳态包括：“在线” 和 “离线” 两个状态。
+OPERATIONDENIED_DOMAINSTATUSUNSTABLE = 'OperationDenied.DomainStatusUnstable'
+
+# 企业版套餐不支持自动续费。
+OPERATIONDENIED_ENTERPRISEPLANAUTORENEWUNSUPPORTED = 'OperationDenied.EnterprisePlanAutoRenewUnsupported'
+
+# 企业版套餐不支持续费。
+OPERATIONDENIED_ENTERPRISEPLANRENEWUNSUPPORTED = 'OperationDenied.EnterprisePlanRenewUnsupported'
+
+# 企业版套餐不支持升级。
+OPERATIONDENIED_ENTERPRISEPLANUPGRADEUNSUPPORTED = 'OperationDenied.EnterprisePlanUpgradeUnsupported'
+
+# 站点环境未准备好。
+OPERATIONDENIED_ENVNOTREADY = 'OperationDenied.EnvNotReady'
+
 # 站点处于停用状态，请开启后重试。
 OPERATIONDENIED_ERRZONEISALREADYPAUSED = 'OperationDenied.ErrZoneIsAlreadyPaused'
 
@@ -608,9 +833,21 @@ OPERATIONDENIED_INVALIDADVANCEDDEFENSESECURITYTYPE = 'OperationDenied.InvalidAdv
 # 开启高防必须保证站点加速区域是国内。
 OPERATIONDENIED_INVALIDADVANCEDDEFENSEZONEAREA = 'OperationDenied.InvalidAdvancedDefenseZoneArea'
 
+# 四层实例资源售卖火爆，已售罄，正在加紧补货中，当前无法新增四层代理，请您耐心等待。
+OPERATIONDENIED_L4LACKOFRESOURCES = 'OperationDenied.L4LackOfResources'
+
+# 四层端口资源售卖火爆，已售罄，正在加紧补货中，当前无法新增四层代理或添加规则，请您耐心等待。
+OPERATIONDENIED_L4PORTLACKOFRESOURCES = 'OperationDenied.L4PortLackOfResources'
+
 # 4层代理资源处于封禁中，禁止操作。
 OPERATIONDENIED_L4PROXYINBANNEDSTATUS = 'OperationDenied.L4ProxyInBannedStatus'
 
+# 4层通道处于关闭状态，不允许添加规则。
+OPERATIONDENIED_L4PROXYINOFFLINESTATUS = 'OperationDenied.L4ProxyInOfflineStatus'
+
+# 实例处于部署中，无法操作。
+OPERATIONDENIED_L4PROXYINPROCESSSTATUS = 'OperationDenied.L4ProxyInProcessStatus'
+
 # 存在四层代理实例处于部署中状态，暂不支持停用站点。
 OPERATIONDENIED_L4PROXYINPROGRESSSTATUS = 'OperationDenied.L4ProxyInProgressStatus'
 
@@ -623,6 +860,9 @@ OPERATIONDENIED_L4STATUSNOTINONLINE = 'OperationDenied.L4StatusNotInOnline'
 # 存在加速域名处于部署中状态，暂不支持停用站点。
 OPERATIONDENIED_L7HOSTINPROCESSSTATUS = 'OperationDenied.L7HostInProcessStatus'
 
+# 绑定负载均衡有处于非运行中的状态，禁止操作。
+OPERATIONDENIED_LOADBALANCESTATUSNOTINONLINE = 'OperationDenied.LoadBalanceStatusNotInOnline'
+
 # 站点状态不支持操作负载均衡。
 OPERATIONDENIED_LOADBALANCINGZONEISNOTACTIVE = 'OperationDenied.LoadBalancingZoneIsNotActive'
 
@@ -638,18 +878,51 @@ OPERATIONDENIED_NODOMAINACCESSZONEONLYALLOWMODIFIEDTOCNAME = 'OperationDenied.No
 # 无域名接入站点不支持除切换为CNAME接入类型以外的任何修改动作。
 OPERATIONDENIED_NODOMAINACCESSZONEONLYSUPPORTMODIFYTYPE = 'OperationDenied.NoDomainAccessZoneOnlySupportModifyType'
 
+# 用户不在版本管理的白名单内。
+OPERATIONDENIED_NOTINVERSIONCONTROLWHITELIST = 'OperationDenied.NotInVersionControlWhiteList'
+
 # 加速域名使用中，无法删除。
 OPERATIONDENIED_ORIGINGROUPACCELERATIONDOMAINUSED = 'OperationDenied.OriginGroupAccelerationDomainUsed'
 
+# 四层代理使用中，无法删除。
+OPERATIONDENIED_ORIGINGROUPL4USED = 'OperationDenied.OriginGroupL4Used'
+
+# 负载均衡使用中，无法删除。
+OPERATIONDENIED_ORIGINGROUPLBUSED = 'OperationDenied.OriginGroupLBUsed'
+
+# 规则引擎使用中，无法删除。
+OPERATIONDENIED_ORIGINGROUPRULEENGINEUSED = 'OperationDenied.OriginGroupRuleEngineUsed'
+
+# 归属权校验未通过，请先完成站点归属权校验。
+OPERATIONDENIED_OWNERSHIPVERIFICATIONNOTPASSED = 'OperationDenied.OwnershipVerificationNotPassed'
+
+# 套餐不支持降级。
+OPERATIONDENIED_PLANDOWNGRADENOTALLOWED = 'OperationDenied.PlanDowngradeNotAllowed'
+
+# 套餐已过期。
+OPERATIONDENIED_PLANHASBEENEXPIRED = 'OperationDenied.PlanHasBeenExpired'
+
+# 套餐已被隔离。
+OPERATIONDENIED_PLANHASBEENISOLATED = 'OperationDenied.PlanHasBeenIsolated'
+
+# 该套餐不支持增购套餐配额。
+OPERATIONDENIED_PLANINCREASEPLANQUOTAUNSUPPORTED = 'OperationDenied.PlanIncreasePlanQuotaUnsupported'
+
 # 套餐不支持变更站点的服务区域。
 OPERATIONDENIED_PLANNOTSUPPORTMODIFYZONEAREA = 'OperationDenied.PlanNotSupportModifyZoneArea'
 
 # Anycast IP调度模式不支持开启中国大陆加速。
 OPERATIONDENIED_PLATTYPEIPACCELERATEMAINLANDNOTSUPPORT = 'OperationDenied.PlatTypeIPAccelerateMainlandNotSupport'
 
+# 如需创建企业版套餐，请联系商务人员。
+OPERATIONDENIED_PLEASECONTACTBUSINESSPERSONNEL = 'OperationDenied.PleaseContactBusinessPersonnel'
+
 # DNS 记录不允许添加。
 OPERATIONDENIED_RECORDISFORBIDDEN = 'OperationDenied.RecordIsForbidden'
 
+# 计费资源操作中，请稍后重试。
+OPERATIONDENIED_RESOURCEHASBEENLOCKED = 'OperationDenied.ResourceHasBeenLocked'
+
 # 当前有互相排斥的请求操作并行发起，请稍后重试。
 OPERATIONDENIED_RESOURCELOCKEDTEMPORARY = 'OperationDenied.ResourceLockedTemporary'
 
@@ -662,12 +935,21 @@ OPERATIONDENIED_SHAREDCNAMEUNSUPPORTEDIPV6 = 'OperationDenied.SharedCNAMEUnsuppo
 # 存在使用中的测试版本，请将测试版本发布现网或者回滚测试版本再重试。
 OPERATIONDENIED_VERSIONCONTROLISGRAYING = 'OperationDenied.VersionControlIsGraying'
 
+# 当前处于版本管理模式下，该操作不允许。
+OPERATIONDENIED_VERSIONCONTROLLOCKED = 'OperationDenied.VersionControlLocked'
+
+# 站点工作模式不属于版本管理模式。
+OPERATIONDENIED_WORKMODENOTINVERSIONCONTROL = 'OperationDenied.WorkModeNotInVersionControl'
+
 # 共享CNAME已被其他站点绑定，请先解绑才能删除站点
 OPERATIONDENIED_ZONEISBINDINGSHAREDCNAME = 'OperationDenied.ZoneIsBindingSharedCNAME'
 
 # 站点存在自定义错误页面引用，请先解绑。
 OPERATIONDENIED_ZONEISREFERENCECUSTOMERRORPAGE = 'OperationDenied.ZoneIsReferenceCustomErrorPage'
 
+# 站点未启用。
+OPERATIONDENIED_ZONENOTACTIVE = 'OperationDenied.ZoneNotActive'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -731,6 +1013,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 最大上传大小额度未配置
 RESOURCENOTFOUND_POSTMAXSIZEQUOTANOTFOUND = 'ResourceNotFound.PostMaxSizeQuotaNotFound'
 
+# 配置组版本不存在，请检查后重试。
+RESOURCENOTFOUND_VERSIONNOTFOUND = 'ResourceNotFound.VersionNotFound'
+
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
@@ -743,6 +1028,9 @@ RESOURCEUNAVAILABLE_DOMAINALREADYEXISTS = 'ResourceUnavailable.DomainAlreadyExis
 # 请求的加速域名不存在，请更正后重试。
 RESOURCEUNAVAILABLE_DOMAINNOTFOUND = 'ResourceUnavailable.DomainNotFound'
 
+# 函数不存在或不属于该账号。
+RESOURCEUNAVAILABLE_FUNCTIONNOTFOUND = 'ResourceUnavailable.FunctionNotFound'
+
 # 域名不存在或未开启代理。
 RESOURCEUNAVAILABLE_HOSTNOTFOUND = 'ResourceUnavailable.HostNotFound'
 
